==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/m365securityandcompliance/kotlin/inputs/ServiceExportConfigurationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.m365securityandcompliance.kotlin.inputs

import com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Export operation configuration information
 * @property storageAccountName The name of the default export storage account.
 */
public data class ServiceExportConfigurationInfoArgs(
    public val storageAccountName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs =
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs.builder()
            .storageAccountName(storageAccountName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceExportConfigurationInfoArgs].
 */
@PulumiTagMarker
public class ServiceExportConfigurationInfoArgsBuilder internal constructor() {
    private var storageAccountName: Output<String>? = null

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("fdlwlxoaarxqrtuu")
    public suspend fun storageAccountName(`value`: Output<String>) {
        this.storageAccountName = value
    }

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("ylqljkaextxypple")
    public suspend fun storageAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountName = mapped
    }

    internal fun build(): ServiceExportConfigurationInfoArgs = ServiceExportConfigurationInfoArgs(
        storageAccountName = storageAccountName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/m365securityandcompliance/kotlin/inputs/ServiceExportConfigurationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.m365securityandcompliance.kotlin.inputs

import com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Export operation configuration information
 * @property storageAccountName The name of the default export storage account.
 */
public data class ServiceExportConfigurationInfoArgs(
    public val storageAccountName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs =
        com.pulumi.azurenative.m365securityandcompliance.inputs.ServiceExportConfigurationInfoArgs.builder()
            .storageAccountName(storageAccountName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceExportConfigurationInfoArgs].
 */
@PulumiTagMarker
public class ServiceExportConfigurationInfoArgsBuilder internal constructor() {
    private var storageAccountName: Output<String>? = null

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("sbxbvrxgippacxlq")
    public suspend fun storageAccountName(`value`: Output<String>) {
        this.storageAccountName = value
    }

    /**
     * @param value The name of the default export storage account.
     */
    @JvmName("nyjcqlmbjkwihnfq")
    public suspend fun storageAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountName = mapped
    }

    internal fun build(): ServiceExportConfigurationInfoArgs = ServiceExportConfigurationInfoArgs(
        storageAccountName = storageAccountName,
    )
}
